@@ -33,6 +33,7 @@ from pandas import DataFrame
 
 import nexinfosys
 from nexinfosys import case_sensitive, SDMXConcept, get_global_configuration_variable
+from nexinfosys.common.decorators import deprecated
 from nexinfosys.ie_imports.google_drive import download_xlsx_file_id
 from nexinfosys.models import log_level
 
@@ -299,7 +300,8 @@ def import_names(package, names):
 # #####################################################################################################################
 
 
-class PartialRetrievalDictionary2:  # DEPRECATED!!!: Use PartialRetrievalDictionary
+@deprecated  # DEPRECATED!!!: Use PartialRetrievalDictionary
+class PartialRetrievalDictionary2:
     """
     Implementation using pd.DataFrame, very slow!!!
 
@@ -562,7 +564,7 @@ class PartialRetrievalDictionary:
         results = self.get(key, key_and_value, full_key, just_oid)
         return results[0] if results else None
 
-    def put(self, key, value):
+    def put(self, key: Dict[Tuple, object], value):
         """
         Insert implies the key does not exist
         Update implies the key exists
@@ -1238,15 +1240,18 @@ def download_file(location, wv_user=None, wv_password=None, wv_host_name=None):
         if pr.netloc.lower() == wv_host_name:
             data = wv_download_file(location, wv_user, wv_password, wv_host_name)
         elif pr.netloc.lower() == "docs.google.com" or pr.netloc.lower() == "drive.google.com":
-            # Google Drive. Only XLSX files supported (if Google Calc, an Export to XLSX is done)
+            # Google Drive. CSV and XLSX files supported (if Google Sheets, an Export to XLSX is done)
             # Extract file id from the URL
             import re
             m = re.match(r".*[^-\w]([-\w]{33,})[^-\w]?.*", location)
             file_id = m.groups()[0]
-            url = f"https://docs.google.com/spreadsheets/d/{file_id}/export?format=xlsx"  # &id={file_id}"
+            if "com/file" not in location:
+                url = f"https://docs.google.com/spreadsheets/d/{file_id}/export?format=xlsx"  # &id={file_id}"
+            else:
+                url = f"https://docs.google.com/uc?export=download&id={file_id}"
             # resp = requests.get(url, headers={'Cache-Control': 'no-cache', 'Pragma': 'no-cache'}, allow_redirects=True)  # headers={'Cache-Control': 'no-cache', 'Pragma': 'no-cache'}
             status_code, headers, data = download_with_pycurl(url)
-            print(f'curl -L "{url}" >> out.xlsx')
+            logging.debug(f'curl -L "{url}" >> out.xlsx')
             if status_code == 200 and "text/html" not in headers["content-type"]:
             # if resp.status_code == 200 and "text/html" not in resp.headers["Content-Type"]:
             #     data = io.BytesIO(resp.content)
@@ -1287,8 +1292,9 @@ def load_dataset(location: str=None):
             location = location[:pos-1]
         # Then, try to read it
         t = mimetypes.guess_type(location, strict=True)
-        if t[0] == "text/csv":
-            df = pd.read_csv(data)
+        if t[0] == "text/csv" or "com/file" in location:
+            data.seek(0)
+            df = pd.read_csv(data, comment="#")
         elif t[0] == "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet" or t[0] == "application/vnd.ms-excel":
             if fragment:
                 df = pd.read_excel(data, sheet_name=fragment)
@@ -1523,7 +1529,7 @@ def replace_string_from_dictionary(s: str, d: Dict[str, str]) -> str:
     :return: a string with replacements applied
     """
     for k, v in sorted(d.items(), key=lambda item: len(item[1])):
-        print(v)
+        logging.debug(v)
         s = re.sub(r"\b" + k + r"\b", v, s)
     return s
 
@@ -1740,7 +1746,7 @@ def get_interfaces_and_weights_from_expression(exp: Union[ArithmeticOperand, Ari
             if is_interface(exp.name):
                 return exp.name, 1.0
             else:
-                print(f"Operand not interface: {exp.name}")
+                logging.debug(f"Operand not interface: {exp.name}")
         elif exp.operator == ArithmeticOperator.MUL:
             interfaces_list: List[Tuple[str, float]] = []
             weight: float = 1.0
@@ -1754,9 +1760,9 @@ def get_interfaces_and_weights_from_expression(exp: Union[ArithmeticOperand, Ari
             if len(interfaces_list) == 1:
                 return interfaces_list[0][0], interfaces_list[0][1] * weight
             elif len(interfaces_list) > 1:
-                print(f"Error multiple interfaces: {interfaces_list}")
+                logging.debug(f"Error multiple interfaces: {interfaces_list}")
         else:
-            print(f"Error operator not allowed: {exp.operator}")
+            logging.debug(f"Error operator not allowed: {exp.operator}")
 
         return None
 
