@@ -175,6 +175,7 @@ class NIS:
             generator_type = "spreadsheet"
             content_type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
             buffer = self._generate_in_memory_excel()
+            print(len(buffer))
             execute = True
             register = False
 
@@ -456,6 +457,7 @@ class NIS:
 
 if __name__ == '__main__':
     examples = [
+        ("https://docs.google.com/spreadsheets/d/1z8QKYkvlUPLAwo6NYM8rRLMj7_QjPRYOgAsTRI2HwWE/edit#gid=1467907392", False),
         ("https://docs.google.com/spreadsheets/d/12AlJ0tdu2b-cfalNzLqFYfiC-hdDlIv1M1pTE3AfSWY/edit#gid=84311637", False),
         ("/home/rnebot/GoogleDrive/AA_PROPUESTAS/Sentinel/Enviro/examples/01_eurostat_datasets.xlsx", False),
         ("/home/rnebot/GoogleDrive/AA_PROPUESTAS/Sentinel/Enviro/examples/howTo Examples SC-Observers.xlsx", True),
